@@ -53,13 +53,13 @@ pvalue<-rep(0,nn)
 for (k in 1:nn) {
 i<-comb[1,k]
 j<-comb[2,k]
-if (means[i, 2] < means[j, 2]){
-comb[1, k]<-j
-comb[2, k]<-i
-}
-dif[k]<-abs(means[i,2]-means[j,2])
+#if (means[i, 2] < means[j, 2]){
+#comb[1, k]<-j
+#comb[2, k]<-i
+#}
+dif[k]<-means[i,2]-means[j,2]
 sdtdif<-sqrt(MSerror * (1/means[i,4] + 1/means[j,4]))
-pvalue[k]<- round(1-ptukey(dif[k]*sqrt(2)/sdtdif,ntr,DFerror),6)
+pvalue[k]<- round(1-ptukey(abs(dif[k])*sqrt(2)/sdtdif,ntr,DFerror),6)
 
 LCL[k] <- dif[k] - Tprob*sdtdif/sqrt(2)
 UCL[k] <- dif[k] + Tprob*sdtdif/sqrt(2)
