@@ -86,13 +86,13 @@ sdtdif <- dif
 for (k in 1:nn) {
 i<-comb[1,k]
 j<-comb[2,k]
-if (means[i, 2] < means[j, 2]){
-comb[1, k]<-j
-comb[2, k]<-i
-}
-dif[k]<-abs(means[i,2]-means[j,2])
+#if (means[i, 2] < means[j, 2]){
+#comb[1, k]<-j
+#comb[2, k]<-i
+#}
+dif[k]<-means[i,2]-means[j,2]
 sdtdif[k]<- sqrt(S*((N-1-H)/(N-ntr))*(1/means[i,3]+1/means[j,3]))
-pvalue[k]<- 2*round(1-pt(dif[k]/sdtdif[k],DFerror),6)
+pvalue[k]<- 2*round(1-pt(abs(dif[k])/sdtdif[k],DFerror),6)
 }
 if (p.adj != "none")pvalue <- round(p.adjust(pvalue, p.adj),6)
 LCL <- dif - Tprob*sdtdif
